/*
    SPDX-FileCopyrightText: 2013 Heena Mahour <heena393@gmail.com>
    SPDX-FileCopyrightText: 2013 Sebastian Kügler <sebas@kde.org>
    SPDX-FileCopyrightText: 2016 Kai Uwe Broulik <kde@privat.broulik.de>
    SPDX-FileCopyrightText: 2023 Boris Pek <bpek@astralinux.ru>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

import QtQuick 2.12
import QtQuick.Layouts 1.12

import org.kde.plasma.plasmoid 2.0
import org.kde.plasma.core 2.0 as PlasmaCore
import org.kde.plasma.components 3.0 as PlasmaComponents3

import org.kde.plasma.workspace.calendar 2.0

Item {
    Plasmoid.backgroundHints: "NoBackground";
    Plasmoid.toolTipMainText: Qt.formatDate(dataSource.data.Local.DateTime, "dddd")
    Plasmoid.toolTipSubText: {
        // this logic is taken from digital-clock:
        // remove "dddd" from the locale format string
        // /all/ locales in LongFormat have "dddd" either
        // at the beginning or at the end. so we just
        // remove it + the delimiter and space
        var format = Qt.locale().dateFormat(Locale.LongFormat);
        format = format.replace(/(^dddd.?\s)|(,?\sdddd$)/, "");
        return Qt.formatDate(dataSource.data.Local.DateTime, format)
    }

    Layout.minimumWidth: PlasmaCore.Units.iconSizes.large
    Layout.minimumHeight: PlasmaCore.Units.iconSizes.large

    PlasmaCore.DataSource {
        id: dataSource
        engine: "time"
        connectedSources: ["Local"]
        interval: 60000
        intervalAlignment: PlasmaCore.Types.AlignToMinute
    }

    Plasmoid.fullRepresentation: Item {
        id: mainItem
        Layout.minimumWidth: Plasmoid.formFactor !== PlasmaCore.Types.Vertical ? mainItem.height : PlasmaCore.Units.gridUnit
        Layout.minimumHeight: Plasmoid.formFactor === PlasmaCore.Types.Vertical ? mainItem.width : PlasmaCore.Units.gridUnit
        Layout.alignment: Qt.AlignHCenter

        Rectangle {
            id: square
            width: Math.min(mainItem.width, mainItem.height)
            height: width
            color: PlasmaCore.Theme.backgroundColor
            radius: 5
            anchors.centerIn: parent

            MouseArea {
                anchors.fill: parent
                onClicked: plasmoid.nativeInterface.launchProgram()
            }

            Item {
                property real padding: 4
                width: square.width - padding * 2
                height: square.height - padding * 2
                anchors.centerIn: parent

                MonthView {
                    id: calendar
                    today: dataSource.data["Local"]["DateTime"]
                    showWeekNumbers: Plasmoid.configuration.showWeekNumbers

                    width: Math.min(parent.width, parent.height)
                    height: width

                    anchors.fill: parent
                }
            }
        }
    }
}
