/*
    SPDX-FileCopyrightText: 2021 Devin Lin <espidev@gmail.com>
    SPDX-FileCopyrightText: 2023 Boris Pek <bpek@astralinux.ru>
    SPDX-License-Identifier: GPL-3.0-or-later
*/

import QtQuick 2.12
import QtQuick.Controls 2.12
import QtQuick.Layouts 1.12
import org.kde.kcm 1.2 as KCM
import org.kde.kirigamiaddons.labs.mobileform 0.1 as MobileForm

KCM.SimpleKCM {
    id: page

    property alias cfg_twelveHourTime: twelveHourTime.checked
    property alias cfg_showDate: showDate.checked
    property alias cfg_showAlarms: showAlarms.checked
    property string cfg_textAlignment


    ColumnLayout {
        Layout.fillWidth: true

        MobileForm.FormCard {
            Layout.fillWidth: true
            contentItem: ColumnLayout {
                MobileForm.FormSwitchDelegate {
                    id: twelveHourTime
                    text: i18n("Use 12 hour time")
                }
                MobileForm.FormSwitchDelegate {
                    id: showDate
                    text: i18n("Show date")
                }
                MobileForm.FormSwitchDelegate {
                    id: showAlarms
                    text: i18n("Show alarms")
                }
                MobileForm.FormComboBoxDelegate {
                    id: textAlignment
                    text: i18n("Text alignment")
                    textRole: 'label'
                    model: [
                        {
                            'label': i18n("Left"),
                            'name': "Left",
                        },
                        {
                            'label': i18n("Center"),
                            'name': "Center",
                        },
                        {
                            'label': i18n("Right"),
                            'name': "Right",
                        }
                    ]
                    onCurrentIndexChanged: cfg_textAlignment = model[currentIndex]["name"]
                    Component.onCompleted: {
                        if (plasmoid.configuration.textAlignment === "") {
                            plasmoid.configuration.textAlignment = "Center";
                        }
                        for (var i = 0; i < model.length; i++) {
                            if (model[i]["name"] === plasmoid.configuration.textAlignment) {
                                textAlignment.currentIndex = i;
                            }
                        }
                    }
                }
            }
        }
    }
}
